@@ -7,8 +7,6 @@
  */
 #include "config.h"
 
-#ifndef LITE
-
 #include "ykey.h"
 #include "yscrollbar.h"
 
@@ -16,55 +14,46 @@
 #include "yprefs.h"
 #include "prefs.h"
 
-YColor *scrollBarBg(NULL);
-static YColor *scrollBarSlider(NULL);
-static YColor *scrollBarButton(NULL);
-static YColor *scrollBarActiveArrow(NULL);
-static YColor *scrollBarInactiveArrow(NULL);
-static bool didInit = false;
+static YColorName scrollBarBg(&clrScrollBar);
+static YColorName scrollBarSlider(&clrScrollBarSlider);
+static YColorName scrollBarButton(&clrScrollBarButton);
+static YColorName scrollBarActiveArrow(&clrScrollBarArrow);
+static YColorName scrollBarInactiveArrow(&clrScrollBarInactive);
 
-YTimer *YScrollBar::fScrollTimer = 0;
-
-static void initColors() {
-    if (didInit)
-        return ;
-    scrollBarBg = new YColor(clrScrollBar);
-    scrollBarSlider= new YColor(clrScrollBarSlider);
-    scrollBarButton= new YColor(clrScrollBarButton);
-    scrollBarActiveArrow = new YColor(clrScrollBarArrow);
-    scrollBarInactiveArrow = new YColor(clrScrollBarInactive);
-    didInit = true;
-}
+lazy<YTimer> YScrollBar::fScrollTimer;
 
 YScrollBar::YScrollBar(YWindow *aParent): YWindow(aParent) {
-    if (!didInit) initColors();
     fOrientation = Vertical;
     fMinimum = fMaximum = fValue = fVisibleAmount = 0;
     fUnitIncrement = fBlockIncrement = 1;
-    fListener = 0;
+    fListener = nullptr;
     fScrollTo = goNone;
     fDNDScroll = false;
+    fConfigured = false;
+    fExposed = false;
+    setTitle("ScrollBar");
 }
 
 
 YScrollBar::YScrollBar(Orientation anOrientation, YWindow *aParent):
 YWindow(aParent)
 {
-    if (!didInit) initColors();
     fOrientation = anOrientation;
 
     fMinimum = fMaximum = fValue = fVisibleAmount = 0;
     fUnitIncrement = fBlockIncrement = 1;
-    fListener = 0;
+    fListener = nullptr;
     fScrollTo = goNone;
     fDNDScroll = false;
+    fConfigured = false;
+    fExposed = false;
+    setTitle("ScrollBar");
 }
 
 YScrollBar::YScrollBar(Orientation anOrientation,
                        int aValue, int aVisibleAmount, int aMin, int aMax,
                        YWindow *aParent): YWindow(aParent)
 {
-    if (!didInit) initColors();
     fOrientation = anOrientation;
     fMinimum = aMin;
     fMaximum = aMax;
@@ -72,13 +61,17 @@ YScrollBar::YScrollBar(Orientation anOrientation,
     fValue = aValue;
 
     fUnitIncrement = fBlockIncrement = 1;
-    fListener = 0;
+    fListener = nullptr;
     fScrollTo = goNone;
+    fDNDScroll = false;
+    fConfigured = false;
+    fExposed = false;
+    setTitle("ScrollBar");
 }
 
 YScrollBar::~YScrollBar() {
-    if (fScrollTimer && fScrollTimer->getTimerListener() == this)
-        fScrollTimer->setTimerListener(0);
+    if (fScrollTimer)
+        fScrollTimer->disableTimerListener(this);
 }
 
 void YScrollBar::setOrientation(Orientation anOrientation) {
@@ -283,9 +276,6 @@ void YScrollBar::paint(Graphics &g, const YRect &/*r*/) {
             g.drawBorderM(0, end + 1, width() - 1, beg - 1, fScrollTo != goDown);
             g.fillRect(2, end + 3, width() - 4, beg - 4);
             break;
-
-        case lookMAX:
-            break;
         }
         // --------------------- upper arrow ---
         g.setColor(fValue > fMinimum ? scrollBarActiveArrow
@@ -314,9 +304,6 @@ void YScrollBar::paint(Graphics &g, const YRect &/*r*/) {
             g.drawArrow(Up, 4, (beg - width() + 12) / 2,
                         width() - 8, fScrollTo == goUp);
             break;
-
-        case lookMAX:
-            break;
         }
         // --------------------- lower arrow ---
         g.setColor(fValue < fMaximum - fVisibleAmount ? scrollBarActiveArrow
@@ -345,9 +332,6 @@ void YScrollBar::paint(Graphics &g, const YRect &/*r*/) {
             g.drawArrow(Down, 4, end + (beg - width() + 14) / 2,
                         width() - 8, fScrollTo == goDown);
             break;
-
-        case lookMAX:
-            break;
         }
 
         g.setColor(scrollBarSlider); // ----------------------------- slider ---
@@ -392,9 +376,6 @@ void YScrollBar::paint(Graphics &g, const YRect &/*r*/) {
             g.drawBorderM(0, y, width() - 1, h + 1, true);
             g.fillRect(2, y + 2, width() - 4, h - 2);
             break;
-
-        case lookMAX:
-            break;
         }
     } else { // ================================================= horizontal ===
         const int x(beg + min), w(max - min);
@@ -466,9 +447,6 @@ void YScrollBar::paint(Graphics &g, const YRect &/*r*/) {
             g.drawBorderM(end + 1, 0, beg - 1, height() - 1, fScrollTo != goDown);
             g.fillRect(end + 3, 2, beg - 4, height() - 4);
             break;
-
-        case lookMAX:
-            break;
         }
         // ---------------------- left arrow ---
         g.setColor(fValue > fMinimum ? scrollBarActiveArrow
@@ -497,9 +475,6 @@ void YScrollBar::paint(Graphics &g, const YRect &/*r*/) {
             g.drawArrow(Left, (beg - height() + 12) / 2, 4,
                         height() - 8, fScrollTo == goUp);
             break;
-
-        case lookMAX:
-            break;
         }
         // --------------------- right arrow ---
         g.setColor(fValue < fMaximum - fVisibleAmount ? scrollBarActiveArrow
@@ -529,9 +504,6 @@ void YScrollBar::paint(Graphics &g, const YRect &/*r*/) {
             g.drawArrow(Right, end + (beg - height() + 14) / 2, 4,
                         height() - 8, fScrollTo == goDown);
             break;
-
-        case lookMAX:
-            break;
         }
 
         g.setColor(scrollBarSlider); // ----------------------------- slider ---
@@ -577,9 +549,6 @@ void YScrollBar::paint(Graphics &g, const YRect &/*r*/) {
             g.drawBorderM(x, 0, w + 1, height() - 1, true);
             g.fillRect(x + 2, 2, w - 2, height() - 4);
             break;
-
-        case lookMAX:
-            break;
         }
     }
 }
@@ -631,20 +600,12 @@ void YScrollBar::handleButton(const XButtonEvent &button) {
     if (button.type == ButtonPress) {
         fScrollTo = getOp(button.x, button.y);
         doScroll();
-        if (fScrollTimer == 0)
-            fScrollTimer = new YTimer(scrollBarStartDelay);
-        if (fScrollTimer) {
-            fScrollTimer->setInterval(scrollBarStartDelay);
-            fScrollTimer->setTimerListener(this);
-            fScrollTimer->startTimer();
-        }
+        fScrollTimer->setTimer(scrollBarStartDelay, this, true);
         repaint();
     } else if (button.type == ButtonRelease) {
         fScrollTo = goNone;
-        if (fScrollTimer && fScrollTimer->getTimerListener() == this) {
-            fScrollTimer->setTimerListener(0);
-            fScrollTimer->stopTimer();
-        }
+        if (fScrollTimer)
+            fScrollTimer->disableTimerListener(this);
         repaint();
     }
 }
@@ -659,11 +620,6 @@ void YScrollBar::handleMotion(const XMotionEvent &motion) {
         if (h <= 0 || fMinimum >= fMaximum)
             return ;
 
-        int min, max;
-
-        min = h * fValue / (fMaximum - fMinimum);
-        max = h * (fValue + fVisibleAmount) / (fMaximum - fMinimum);
-
         if (fScrollTo == goPosition) {
             int y = motion.y - fGrabDelta - width();
             if (y < 0) y = 0;
@@ -676,11 +632,6 @@ void YScrollBar::handleMotion(const XMotionEvent &motion) {
         if (w <= 0 || fMinimum >= fMaximum)
             return ;
 
-        int min, max;
-
-        min = w * fValue / (fMaximum - fMinimum);
-        max = w * (fValue + fVisibleAmount) / (fMaximum - fMinimum);
-
         if (fScrollTo == goPosition) {
             int x = motion.x - fGrabDelta - height();
             if (x < 0) x = 0;
@@ -692,22 +643,110 @@ void YScrollBar::handleMotion(const XMotionEvent &motion) {
 
 bool YScrollBar::handleScrollKeys(const XKeyEvent &key) {
     if (key.type == KeyPress) {
-        KeySym k = XKeycodeToKeysym(xapp->display(), key.keycode, 0);
+        KeySym k = keyCodeToKeySym(key.keycode);
         int m = KEY_MODMASK(key.state);
 
-        switch (k) {
-        case XK_Prior:
-            if (m & ControlMask)
+        if (fOrientation == Vertical) {
+            switch (k) {
+            case XK_Up:
+            case XK_KP_Up:
+                if (m == 0) {
+                    scroll(-fUnitIncrement);
+                    return true;
+                }
+                if (m == ShiftMask) {
+                    scroll(-fUnitIncrement * 4);
+                    return true;
+                }
+                if (m == ControlMask) {
+                    scroll(-fUnitIncrement * 16);
+                    return true;
+                }
+                break;
+            case XK_Home:
+            case XK_KP_Home:
+                if (m == 0) {
+                    move(0);
+                    return true;
+                }
+                break;
+            case XK_Prior:
+            case XK_KP_Prior:
+                if (m == ControlMask) {
+                    move(0);
+                    return true;
+                }
+                if (m == ShiftMask) {
+                    scroll(-fBlockIncrement * 4);
+                    return true;
+                }
+                if (m == 0) {
+                    scroll(-fBlockIncrement);
+                    return true;
+                }
+                break;
+            case XK_Down:
+            case XK_KP_Down:
+                if (m == 0) {
+                    scroll(+fUnitIncrement);
+                    return true;
+                }
+                if (m == ShiftMask) {
+                    scroll(+fUnitIncrement * 4);
+                    return true;
+                }
+                if (m == ControlMask) {
+                    scroll(+fUnitIncrement * 16);
+                    return true;
+                }
+                break;
+            case XK_End:
+            case XK_KP_End:
+                if (m == 0) {
+                    move(fMaximum - fVisibleAmount);
+                    return true;
+                }
+                break;
+            case XK_Next:
+            case XK_KP_Next:
+                if (m == ControlMask) {
+                    move(fMaximum - fVisibleAmount);
+                    return true;
+                }
+                if (m == ShiftMask) {
+                    scroll(+fBlockIncrement * 4);
+                    return true;
+                }
+                if (m == 0) {
+                    scroll(+fBlockIncrement);
+                    return true;
+                }
+                break;
+            default:
+                break;
+            }
+        }
+        else if (m == 0 && fOrientation == Horizontal) {
+            switch (k) {
+            case XK_Left:
+            case XK_KP_Left:
+                scroll(-fUnitIncrement);
+                return true;
+            case XK_Right:
+            case XK_KP_Right:
+                scroll(+fUnitIncrement);
+                return true;
+            case XK_Home:
+            case XK_KP_Home:
                 move(0);
-            else
-                scroll(-fBlockIncrement);
-            return true;
-        case XK_Next:
-            if (m & ControlMask)
+                return true;
+            case XK_End:
+            case XK_KP_End:
                 move(fMaximum - fVisibleAmount);
-            else
-                scroll(+fBlockIncrement);
-            return true;
+                return true;
+            default:
+                break;
+            }
         }
     }
     return false;
@@ -805,31 +844,42 @@ YScrollBar::ScrollOp YScrollBar::getOp(int x, int y) {
 void YScrollBar::handleDNDEnter() {
     fScrollTo = goNone;
     fDNDScroll = true;
-    if (fScrollTimer && fScrollTimer->getTimerListener() == this) {
-        fScrollTimer->setTimerListener(0);
-        fScrollTimer->stopTimer();
-    }
+    if (fScrollTimer)
+        fScrollTimer->disableTimerListener(this);
 }
 
 void YScrollBar::handleDNDLeave() {
     fScrollTo = goNone;
     fDNDScroll = false;
     repaint();
-    if (fScrollTimer && fScrollTimer->getTimerListener() == this) {
-        fScrollTimer->setTimerListener(0);
-        fScrollTimer->stopTimer();
-    }
+    if (fScrollTimer)
+        fScrollTimer->disableTimerListener(this);
 }
 
 void YScrollBar::handleDNDPosition(int x, int y) {
     fScrollTo = getOp(x, y);
-    if (fScrollTimer == 0)
-        fScrollTimer = new YTimer(scrollBarStartDelay);
-    if (fScrollTimer) {
-        fScrollTimer->setInterval(scrollBarStartDelay);
-        fScrollTimer->setTimerListener(this);
-        fScrollTimer->startTimer();
-    }
+    fScrollTimer->setTimer(scrollBarStartDelay, this, true);
     repaint();
 }
-#endif
+
+void YScrollBar::configure(const YRect2& r) {
+    if (r.width() > 1 && r.height() > 1) {
+        fConfigured = true;
+        repaint();
+    }
+}
+
+void YScrollBar::handleExpose(const XExposeEvent &expose) {
+    if (fExposed == false && expose.count == 0) {
+        fExposed = true;
+        repaint();
+    }
+}
+
+void YScrollBar::repaint() {
+    if (fConfigured && fExposed) {
+        GraphicsBuffer(this).paint();
+    }
+}
+
+// vim: set sw=4 ts=4 et:
